@@ -1,6 +1,8 @@
 import ast
 import numpy as np
+import pandas as pd
 import pickle
+import scipy.stats as st
 
 from collections import Counter
 from sklearn.base import BaseEstimator, ClassifierMixin
@@ -9,17 +11,14 @@ from tensorflow.keras.models import model_from_json
 from tensorflow.keras.preprocessing.sequence import pad_sequences
 from tensorflow.keras.optimizers import Adam
 from tensorflow.keras.callbacks import TensorBoard
-from transformers import CamembertTokenizer, XLMTokenizer
-from transformers import TFCamembertModel, TFFlaubertModel
 
-from melusine.config.config import ConfigJsonReader
+from melusine import config
 from melusine.nlp_tools.tokenizer import Tokenizer
 from melusine.models.attention_model import PositionalEncoding
 from melusine.models.attention_model import TransformerEncoderLayer
 from melusine.models.attention_model import MultiHeadAttention
 
-conf_reader = ConfigJsonReader()
-config = conf_reader.get_config_file()
+
 tensorboard_callback_parameters = config["tensorboard_callback"]
 
 
@@ -100,9 +99,9 @@ class NeuralModel(BaseEstimator, ClassifierMixin):
     >>> from melusine.nlp_tools.embedding import Embedding
     >>> pretrained_embedding = Embedding.load()
     >>> list_meta = ['extension', 'dayofweek', 'hour']
-    >>> nn_model = NeuralModel(cnn_model, pretrained_embedding, list_meta)
-    >>> nn_model.fit(X_train, y_train)
-    >>> y_res = nn_model.predict(X_test)
+    >>> nn_model = NeuralModel(cnn_model, pretrained_embedding, list_meta)  #noqa
+    >>> nn_model.fit(X_train, y_train)  #noqa
+    >>> y_res = nn_model.predict(X_test)  #noqa
 
     """
 
@@ -111,7 +110,7 @@ class NeuralModel(BaseEstimator, ClassifierMixin):
         pretrained_embedding=None,
         architecture_function=None,
         text_input_column="clean_text",
-        meta_input_list=["extension", "dayofweek", "hour", "min"],
+        meta_input_list=("extension", "dayofweek", "hour", "min"),
         vocab_size=25000,
         seq_size=100,
         embedding_dim=200,
@@ -121,19 +120,41 @@ class NeuralModel(BaseEstimator, ClassifierMixin):
         n_epochs=15,
         bert_tokenizer="jplu/tf-camembert-base",
         bert_model="jplu/tf-camembert-base",
+        tokenizer=Tokenizer(),
         **kwargs,
     ):
         self.architecture_function = architecture_function
         self.pretrained_embedding = pretrained_embedding
+        self.bert_tokenizer = bert_tokenizer
         if self.architecture_function.__name__ != "bert_model":
-            self.tokenizer = Tokenizer(input_column=text_input_column)
-        elif "camembert" in bert_tokenizer.lower():
-            self.tokenizer = CamembertTokenizer.from_pretrained(bert_tokenizer)
-        elif "flaubert" in bert_tokenizer.lower():
-            self.tokenizer = XLMTokenizer.from_pretrained(bert_tokenizer)
+            self.tokenizer = tokenizer
+            self.tokenizer.input_column = text_input_column
+        
+        elif "camembert" in self.bert_tokenizer.lower():
+            # Prevent the HuggingFace dependency
+            try:
+                from transformers import CamembertTokenizer
+
+                self.tokenizer = CamembertTokenizer.from_pretrained(self.bert_tokenizer)
+            except ModuleNotFoundError:
+                raise (
+                    """Please install transformers 3.4.0 (only version currently supported)
+                    pip install melusine[transformers]"""
+                )
+        elif "flaubert" in self.bert_tokenizer.lower():
+            # Prevent the HuggingFace dependency
+            try:
+                from transformers import XLMTokenizer
+
+                self.tokenizer = XLMTokenizer.from_pretrained(self.bert_tokenizer)
+            except ModuleNotFoundError:
+                raise (
+                    """Please install transformers 3.4.0 (only version currently supported)
+                    pip install melusine[transformers]"""
+                )
         else:
             raise NotImplementedError(
-                "Bert tokenizer {} not implemented".format(bert_tokenizer)
+                "Bert tokenizer {} not implemented".format(self.bert_tokenizer)
             )
         self.text_input_column = text_input_column
         self.meta_input_list = meta_input_list
@@ -158,7 +179,7 @@ class NeuralModel(BaseEstimator, ClassifierMixin):
             open(filepath + ".json", "w").write(json_model)
             self.model.save_weights(filepath + "_model_weights.h5", overwrite=True)
         else:
-            with open(filepath + "bert_params.pkl", "wb") as f:
+            with open(filepath + "_bert_params.pkl", "wb") as f:
                 pickle.dump([self.nb_labels, self.nb_meta_features], f)
             self.model.save_weights(filepath + "_model_weights", overwrite=True)
         pass
@@ -178,7 +199,7 @@ class NeuralModel(BaseEstimator, ClassifierMixin):
             model.load_weights(filepath + "_model_weights.h5")
             model.compile(optimizer=Adam(), loss=self.loss, metrics=["accuracy"])
         else:
-            with open(filepath + "bert_params.pkl", "rb") as f:
+            with open(filepath + "_bert_params.pkl", "rb") as f:
                 nb_labels, nb_meta_features = pickle.load(f)
             model = self.architecture_function(
                 ntargets=nb_labels,
@@ -199,6 +220,7 @@ class NeuralModel(BaseEstimator, ClassifierMixin):
         dict_attr = dict(self.__dict__)
         if "model" in dict_attr:
             del dict_attr["model"]
+        if "embedding_matrix" in dict_attr:
             del dict_attr["embedding_matrix"]
             del dict_attr["pretrained_embedding"]
         return dict_attr
@@ -260,7 +282,7 @@ class NeuralModel(BaseEstimator, ClassifierMixin):
                 validation_data = (X_input_val, y_categorical_val)
 
         if tensorboard_log_dir is None:
-            self.model.fit(
+            hist = self.model.fit(
                 X_input_train,
                 y_categorical_train,
                 batch_size=self.batch_size,
@@ -314,7 +336,7 @@ class NeuralModel(BaseEstimator, ClassifierMixin):
                 embeddings_data=embeddings_data,
                 update_freq=update_freq,
             )
-            self.model.fit(
+            hist = self.model.fit(
                 X_input_train,
                 y_categorical_train,
                 batch_size=self.batch_size,
@@ -323,7 +345,7 @@ class NeuralModel(BaseEstimator, ClassifierMixin):
                 validation_data=validation_data,
                 **kwargs,
             )
-        pass
+        return hist
 
     def predict(self, X, **kwargs):
         """Returns the class predicted.
@@ -343,15 +365,57 @@ class NeuralModel(BaseEstimator, ClassifierMixin):
         If meta_input list is empty list or None the model is used
         without metadata.
 
+        Parameters
+        ----------
+        X : pd.DataFrame
+        prediction_interval : float, optional
+            between [0,1], the confidence level of the interval.
+            Only available with tensorflow-probability models.
+        Returns
+        -------
+        score : np.array
+            The estimation of probability for each category.
+        inf : np.array, optional
+            The upper bound of the estimation of probability.
+            Only provided if `prediction_interval` exists.
+        sup : np.array, optional
+            The lower bound of the estimation of probability.
+            Only provided if `prediction_interval` exists.
+        """
+
+        X_input = self.prepare_email_to_predict(X)
+        if self.model.layers[-1].get_config().get('convert_to_tensor_fn') == 'mode':
+            # tensorflow_probabilty model : the output is a distribution so we return the mean of the distribution
+            score = self.model(X_input).mean().numpy()
+            if "prediction_interval" in kwargs:
+                confidence_level = kwargs["prediction_interval"]
+                std = self.model(X_input).stddev()
+                two_sided_mult = st.norm.ppf((1+confidence_level)/2) # 1.96 for 0.95
+                inf = np.clip(a=score-two_sided_mult*std.numpy(), a_min=0, a_max=1)
+                sup = np.clip(a=score+two_sided_mult*std.numpy(), a_min=0, a_max=1)
+                return score, inf, sup
+            return score
+        else:
+            score = self.model.predict(X_input, **kwargs)
+            return score
+    
+    def prepare_email_to_predict(self, X):
+        """Returns the email as a compatible shape
+        wich depends on the type of neural model
+
         Parameters
         ----------
         X : pd.DataFrame
 
         Returns
         -------
-        np.array
+        list
+            List of the inputs to the neural model
+            Either [X_seq] if no metadata
+            Or [X_seq, X_meta] if metadata
+            Or [X_seq, X_attention, X_meta] if Bert model
         """
-
+        
         if self.architecture_function.__name__ != "bert_model":
             X = self.tokenizer.transform(X)
             X_seq = self._prepare_sequences(X)
@@ -364,10 +428,10 @@ class NeuralModel(BaseEstimator, ClassifierMixin):
             X_seq, X_attention = self._prepare_bert_sequences(X)
             X_meta, nb_meta_features = self._get_meta(X)
             if nb_meta_features == 0:
-                X_input = [X_seq, X_meta]
+                X_input = [X_seq, X_attention]
             else:
                 X_input = [X_seq, X_attention, X_meta]
-        return self.model.predict(X_input, **kwargs)
+        return X_input
 
     def _create_vocabulary_from_tokens(self, X):
         """Create a word indexes dictionary from tokens."""
@@ -382,15 +446,13 @@ class NeuralModel(BaseEstimator, ClassifierMixin):
         The vocabulary of the NN is those of the pretrained embedding
         """
         pretrained_embedding = self.pretrained_embedding
-        self.vocabulary = pretrained_embedding.embedding.wv.index2word
+        self.vocabulary = pretrained_embedding.embedding.index_to_key
         vocab_size = len(self.vocabulary)
         vector_dim = pretrained_embedding.embedding.vector_size
         embedding_matrix = np.zeros((vocab_size + 2, vector_dim))
         for index, word in enumerate(self.vocabulary):
             if word not in ["PAD", "UNK"]:
-                embedding_matrix[
-                    index + 2, :
-                ] = pretrained_embedding.embedding.wv.get_vector(word)
+                embedding_matrix[index + 2, :] = pretrained_embedding.embedding[word]
         embedding_matrix[1, :] = np.mean(embedding_matrix, axis=0)
 
         self.vocabulary.insert(0, "PAD")
@@ -498,14 +560,27 @@ class NeuralModel(BaseEstimator, ClassifierMixin):
                 self.vocabulary_dict = {
                     word: i for i, word in enumerate(self.vocabulary)
                 }
-                self.model = self.architecture_function(
-                    embedding_matrix_init=self.embedding_matrix,
-                    ntargets=nb_labels,
-                    seq_max=self.seq_size,
-                    nb_meta=nb_meta_features,
-                    loss=self.loss,
-                    activation=self.activation,
-                )
+                if self.architecture_function.__name__ == "flipout_cnn_model":
+                    # this variational model needs also the size of the training dataset
+                    training_data_size = len(X)
+                    self.model = self.architecture_function(
+                        embedding_matrix_init=self.embedding_matrix,
+                        ntargets=nb_labels,
+                        seq_max=self.seq_size,
+                        nb_meta=nb_meta_features,
+                        loss=self.loss,
+                        activation=self.activation,
+                        training_data_size=training_data_size
+                    )
+                else:
+                    self.model = self.architecture_function(
+                        embedding_matrix_init=self.embedding_matrix,
+                        ntargets=nb_labels,
+                        seq_max=self.seq_size,
+                        nb_meta=nb_meta_features,
+                        loss=self.loss,
+                        activation=self.activation,
+                    )
 
             X_seq = self._prepare_sequences(X)
 
@@ -536,7 +611,7 @@ class NeuralModel(BaseEstimator, ClassifierMixin):
         return X_input, y_categorical
 
     def _get_meta(self, X):
-        """Returns as a pd.DataFrame the metadata from X given the list_meta
+        """Returns as a np.array the metadata from X given the list_meta
         defined, and returns the number of columns. If meta_input_list is
         empty list or None, meta_input_list is returned as 0."""
         if self.meta_input_list is None or self.meta_input_list == []:
@@ -554,7 +629,6 @@ class NeuralModel(BaseEstimator, ClassifierMixin):
             meta_columns_list = [
                 col for col in columns_list if col.startswith(tuple(meta_input_list))
             ]
-
             if isinstance(X, dict):
                 X_meta = np.array(
                     [
@@ -563,7 +637,7 @@ class NeuralModel(BaseEstimator, ClassifierMixin):
                 )
             else:
                 X_meta = X[meta_columns_list]
-
             nb_meta_features = len(meta_columns_list)
-
+        if isinstance(X_meta, pd.DataFrame):
+            X_meta = X_meta.to_numpy()
         return X_meta, nb_meta_features
