@@ -32,7 +32,8 @@ class MetaExtension(BaseEstimator, TransformerMixin):
         X["extension"] = X.apply(
             self.encode_extension, args=(self.top_extension,), axis=1
         )
-        self.le_extension.fit(X["extension"])
+        # We add the value "other" for the training of the label encoder to deal with unseen values of metadatas during inference !
+        self.le_extension.fit(pd.concat((X["extension"], pd.Series(["other"]))))
         return self
 
     def transform(self, X):
@@ -133,12 +134,6 @@ class MetaDate(BaseEstimator, TransformerMixin):
 
         """Transform date to hour, min, day features."""
         X["date"] = apply_func(X, self.date_formatting, args_=(self.regex_date_format,))
-        X["date"] = pd.to_datetime(
-            X["date"],
-            format=self.date_format,
-            infer_datetime_format=False,
-            errors="coerce",
-        )
         X["hour"] = apply_func(X, self.get_hour)
         X["min"] = apply_func(X, self.get_min)
         X["dayofweek"] = apply_func(X, self.get_dayofweek)
@@ -152,8 +147,14 @@ class MetaDate(BaseEstimator, TransformerMixin):
             date = e[0] + "/" + e[1] + "/" + e[2] + " " + e[3] + ":" + e[4]
             for m, m_n in self.month.items():
                 date = date.replace(m, m_n)
+            date = pd.to_datetime(
+                date,
+                format=self.date_format,
+                infer_datetime_format=False,
+                errors="coerce",
+            )
         except Exception:
-            return x
+            return pd.to_datetime(x)
         return date
 
     @staticmethod
@@ -301,11 +302,14 @@ class MetaAttachmentType(BaseEstimator, TransformerMixin):
 
         """ Fit LabelEncoder on encoded extensions."""
         X["attachment_type"] = X.apply(self.get_attachment_type, axis=1)
-        self.top_attachment_type = self.get_top_attachment_type(X, n=self.topn_extension)
+        self.top_attachment_type = self.get_top_attachment_type(
+            X, n=self.topn_extension
+        )
         X["attachment_type"] = X.apply(
             self.encode_type, args=(self.top_attachment_type,), axis=1
         )
-        self.le_extension.fit(X["attachment_type"].sum())
+        # We add the value "other" for the trainign of the label encoder to deal with unseen values during inference !
+        self.le_extension.fit(pd.concat((X["attachment_type"], pd.Series([['other']]))).sum())
         return self
 
     def transform(self, X):
