@@ -5,6 +5,8 @@ import ast
 from sklearn.pipeline import Pipeline
 from sklearn.preprocessing import LabelEncoder
 
+from melusine.models.neural_architectures import cnn_model
+from melusine.models.train import NeuralModel
 from melusine.utils.transformer_scheduler import TransformerScheduler
 
 from melusine.prepare_email.manage_transfer_reply import check_mail_begin_by_transfer
@@ -19,8 +21,6 @@ from melusine.prepare_email.cleaning import clean_body
 from melusine.prepare_email.cleaning import clean_header
 
 from melusine.nlp_tools.phraser import Phraser
-from melusine.nlp_tools.phraser import phraser_on_body
-from melusine.nlp_tools.phraser import phraser_on_header
 from melusine.nlp_tools.tokenizer import Tokenizer
 from melusine.nlp_tools.embedding import Embedding
 from melusine.summarizer.keywords_generator import KeywordsGenerator
@@ -30,18 +30,9 @@ from melusine.prepare_email.metadata_engineering import MetaDate
 from melusine.prepare_email.metadata_engineering import MetaAttachmentType
 from melusine.prepare_email.metadata_engineering import Dummifier
 
-from melusine.models.neural_architectures import cnn_model
-from melusine.models.train import NeuralModel
-
 from melusine.data.data_loader import load_email_data
 
-body = "Bonjour\nThis is Melusine\nCordialement\nDev Team"
-header = "Test integration Melusine"
-body = "Bonjour\nThis is Melusine\nCordialement\nDev Team"
-body = "Bonjour\nThis is Melusine\nCordialement\nDev Team"
-body = "Bonjour\nThis is Melusine\nCordialement\nDev Team"
-
-
+# Prevent GPU usage
 os.environ["CUDA_DEVICE_ORDER"] = "PCI_BUS_ID"
 os.environ["CUDA_VISIBLE_DEVICES"] = ""
 
@@ -50,13 +41,8 @@ def test_classification():
 
     input_df = load_email_data()
 
-    # ============== Train Phraser ==============
-    phraser = Phraser(input_column="body", threshold=10, min_count=10)
-
-    phraser.train(input_df)
-
     # ============== Define Transformer Schedulers ==============
-    ManageTransferReply = TransformerScheduler(
+    manageTransferReply = TransformerScheduler(
         functions_scheduler=[
             (check_mail_begin_by_transfer, None, ["is_begin_by_transfer"]),
             (update_info_for_transfer_mail, None, None),
@@ -65,13 +51,13 @@ def test_classification():
         ]
     )
 
-    Segmenting = TransformerScheduler(
+    segmenting = TransformerScheduler(
         functions_scheduler=[
             (build_historic, None, ["structured_historic"]),
             (structure_email, None, ["structured_body"]),
         ]
     )
-    LastBodyHeaderCleaning = TransformerScheduler(
+    lastBodyHeaderCleaning = TransformerScheduler(
         functions_scheduler=[
             (extract_last_body, None, ["last_body"]),
             (clean_body, None, ["clean_body"]),
@@ -79,33 +65,28 @@ def test_classification():
         ]
     )
 
-    # ============== Phraser ==============
-    PhraserTransformer = TransformerScheduler(
-        functions_scheduler=[
-            (phraser_on_body, (phraser,), ["clean_body"]),
-            (phraser_on_header, (phraser,), ["clean_header"]),
-        ]
-    )
-
     # ============== Tokenizer ==============
     tokenizer = Tokenizer(input_column="clean_body")
 
+    # ============== Phraser ==============
+    phraser = Phraser(threshold=10, min_count=10)
+
     # ============== Full Pipeline ==============
-    PreprocessingPipeline = Pipeline(
+    preprocessingPipeline = Pipeline(
         [
-            ("ManageTransferReply", ManageTransferReply),
-            ("Segmenting", Segmenting),
-            ("LastBodyHeaderCleaning", LastBodyHeaderCleaning),
-            ("PhraserTransformer", PhraserTransformer),
+            ("ManageTransferReply", manageTransferReply),
+            ("Segmenting", segmenting),
+            ("LastBodyHeaderCleaning", lastBodyHeaderCleaning),
             ("tokenizer", tokenizer),
+            ("phraser", phraser),
         ]
     )
 
     # ============== Transform input DataFrame ==============
-    input_df = PreprocessingPipeline.transform(input_df)
+    input_df = preprocessingPipeline.fit_transform(input_df)
 
     # ============== MetaData Pipeline ==============
-    MetadataPipeline = Pipeline(
+    metadataPipeline = Pipeline(
         [
             ("MetaExtension", MetaExtension()),
             ("MetaDate", MetaDate()),
@@ -116,14 +97,14 @@ def test_classification():
 
     # ============== Transform MetaData ==============
     input_df["attachment"] = input_df["attachment"].apply(ast.literal_eval)
-    df_meta = MetadataPipeline.fit_transform(input_df)
+    df_meta = metadataPipeline.fit_transform(input_df)
 
     # ============== Keywords Generator ==============
     keywords_generator = KeywordsGenerator(n_max_keywords=4)
     input_df = keywords_generator.fit_transform(input_df)
 
     # ============== Embeddings ==============
-    pretrained_embedding = Embedding(input_column="clean_body", workers=1, min_count=5)
+    pretrained_embedding = Embedding(tokens_column="tokens", workers=1, min_count=5)
     pretrained_embedding.train(input_df)
 
     # ============== CNN Classifier ==============
@@ -136,8 +117,16 @@ def test_classification():
         architecture_function=cnn_model,
         pretrained_embedding=pretrained_embedding,
         text_input_column="clean_body",
-        meta_input_list=["extension", "dayofweek", "hour", "min", "attachment_type"],
+        meta_input_list=[
+            "extension",
+            "dayofweek",
+            "hour",
+            "min",
+            "attachment_type",
+        ],
         n_epochs=2,
+        seq_size=8,
+        batch_size=8,
     )
 
     nn_model.fit(X, y)
@@ -147,7 +136,7 @@ def test_classification():
 
     # ============== Test dict compatibility ==============
     dict_emails = input_df.to_dict(orient="records")[0]
-    dict_meta = MetadataPipeline.transform(dict_emails)
+    dict_meta = metadataPipeline.transform(dict_emails)
     keywords_generator.transform(dict_emails)
 
     dict_input = copy.deepcopy(dict_meta)
